summaryrefslogtreecommitdiff
path: root/cflags.SH
diff options
context:
space:
mode:
authorJarkko Hietaniemi <jhi@iki.fi>2006-09-19 12:19:22 +0300
committerH.Merijn Brand <h.m.brand@xs4all.nl>2006-09-19 06:45:26 +0000
commita7ae1e4a956bbd5ffa44d286e0591bf4c0e7c341 (patch)
tree3b47c791b76ba61d8e2527a4479c047b99251d21 /cflags.SH
parent9a4997407636e1eeb1029b89852e85209dd9461d (diff)
downloadperl-a7ae1e4a956bbd5ffa44d286e0591bf4c0e7c341.tar.gz
C++: add -Wno-used-parameter, and drop ODBM_File
Message-ID: <450F8BEA.1010802@iki.fi> p4raw-id: //depot/perl@28867
Diffstat (limited to 'cflags.SH')
-rwxr-xr-xcflags.SH12
1 files changed, 8 insertions, 4 deletions
diff --git a/cflags.SH b/cflags.SH
index 966901a935..95f846b683 100755
--- a/cflags.SH
+++ b/cflags.SH
@@ -234,10 +234,14 @@ esac
case "$cc" in
*g++*)
# Without -Wno-unused-variable g++ 4.x compiles are rather unwatchable
- # because of all the warnings about Perl___notused, and g++ doesn't
- # do __attribute__((unused)) (and even if at some stage it will), people
- # do have older gcc installations. Yes, we lose some valid warnings.
- for o in -Wno-unused-variable
+ # because of all the warnings about Perl___notused, and g++ doesn't do
+ # __attribute__((unused)) (and even if at some stage it may, people do
+ # have older gcc installations), and ((void)x) isn't enough to silence
+ # the noises about XS functions not using their cv parameter, so we need
+ # the -Wno-unused-parameter too.
+ # Yes, we lose some valid warnings, but hopefully other compilers
+ # (like gcc) will still pick up those warnings.
+ for o in -Wno-unused-variable -Wno-unused-parameter
do
case "$warn" in
*$o*) ;;